@@ -11,12 +11,12 @@
 print.simmr_output <-
   function(x, ...) {
     if (inherits(x, "simmr_output") == TRUE) {
-      if (inherits(x, "simmr_mcmc") == TRUE) {
+      if (inherits(x, "simmr_mcmc_object") == TRUE) {
         print(x$input)
         message("The input data has been run via simmr_mcmc and has produced ")
         message(nrow(x$output[[1]]$BUGSoutput$sims.matrix), " iterations over ", x$output[[1]]$BUGSoutput$n.chains, " MCMC chains.")
         message("\n\n")
-      } else if (inherits(x, "simmr_ffvb") == TRUE) {
+      } else if (inherits(x, "simmr_ffvb_object") == TRUE) {
         print(x$input)
         message("The input data has been run via simmr_ffvb and has produced ")
         message(nrow(x$output[[1]]$BUGSoutput$sims.list$p), " samples.")
